@@ -175,21 +175,24 @@ void BackgroundDlg::loadThemes()
         if(!themeBgs.isEmpty()) {
             QFile file(themeConf);
             if (!file.open(QIODevice::ReadOnly | QIODevice::Text)) {
-                 QMessageBox::warning(this,"Error with theme config","Failed to load theme name from config",
-                         QMessageBox::NoButton,QMessageBox::NoButton);
-                return;
+                 QMessageBox::warning(this,"Error with theme config","Couldn't load " + themeDirList.at(i) + " theme config file!" +
+                                 " Please download theme again from theme manager.",
+                                 QMessageBox::NoButton,QMessageBox::NoButton);
+                themeDirList.removeAt(i);
+                i--;
             }
+            else {
+                QTextStream in(&file);
+                while (!in.atEnd()) {
+                    QString line = in.readLine();
+                    process_line(line, THEME);
+                }
 
-            QTextStream in(&file);
-            while (!in.atEnd()) {
-                QString line = in.readLine();
-                process_line(line, THEME);
+                item->setText(themeName);
+
+                m_ui->listWidget->insertItem(i, item);
+                m_ui->listWidget->show();
             }
-
-            item->setText(themeName);
-
-            m_ui->listWidget->insertItem(i, item);
-            m_ui->listWidget->show();
         }
         else {
                 themeDirList.removeAt(i);
