@@ -60,7 +60,7 @@ void CreateBackgroundDlg::changeEvent(QEvent *e)
 
 void CreateBackgroundDlg::on_addPushButton_clicked()
 {
-    if(!edit) {
+    if(!edit && !m_ui->lineEdit->text().isEmpty()) {
         for(int i=0;i<backgrounds->count();i++) {
             if(backgrounds->at(i)->name == m_ui->lineEdit->text()) {
                 QMessageBox::warning(this,"Background name already exists!","Please choose a different background name.",
@@ -71,7 +71,7 @@ void CreateBackgroundDlg::on_addPushButton_clicked()
         emit createBackground(m_ui->lineEdit->text(),background, fileName);
         this->close();
     }
-    if(edit) {
+    if(edit && !m_ui->lineEdit->text().isEmpty()) {
         for(int i=0;i<backgrounds->count();i++) {
             if(backgrounds->at(i)->name == m_ui->lineEdit->text() && m_ui->lineEdit->text() != bg->name) {
                 QMessageBox::warning(this,"Background name already exists!","Please choose a different background name.",
