@@ -128,7 +128,7 @@ void DownloadRemoteDlg::processReturnValue(int Id,QVariant data)
 
             QString para = modelItem;
             if(remoteStartup) {
-                remotestartupdlg = new RemoteStartupDlg(para, this);
+                remotestartupdlg = new RemoteStartupDlg(para, this, remoteNames);
                 connect(remotestartupdlg,SIGNAL(addButtonToLayoutSignalFromRSD(QString,QString,QString,QString,QStringList,int)),this,SLOT(AddButtonToLayout(QString, QString,QString,QString,QStringList,int)));
                 connect(remotestartupdlg,SIGNAL(remoteCreated(QString)),this,SLOT(enableRemoteNameAdding(QString)));
                 connect(remotestartupdlg,SIGNAL(lwClear()),this,SLOT(clearScreenForNewRemote()));
