@@ -514,9 +514,9 @@ void QtIrreco::about()
 
 void QtIrreco::theme()
 {
-    ThemeManager *theme = new ThemeManager(this);
-    theme->exec();
-    delete theme;
+    ThemeManager *themeDlg = new ThemeManager(this);
+    themeDlg->exec();
+    delete themeDlg;
 }
 
 void QtIrreco::newButton()
