@@ -361,7 +361,6 @@ void ThemeManager::processReturnValue(int Id,QVariant data)
         dbBackgroundIdsList = sList;
         if(dbBackgroundIdsList.count() > 0 && !dbBackgroundIdsList.contains("0"))
         {
-           // this->setWindowTitle(dbBackgroundIdsList.at(0));
             this->setWindowTitle("Downloading theme backgrounds...");
             this->getThemeBackgroundsByIds();
         }
@@ -875,16 +874,25 @@ void ThemeManager::on_deletePushButton_clicked()
     QStringList remoteFiles = dir.entryList(QDir::Files);
 
     for(int i=0;i<remoteFiles.count();i++) {
-        if(remoteFiles.at(i) == "remotes.conf") {
-            remoteFiles.removeAt(i);
-        }
-        if(!remoteFiles.isEmpty()) {
-            QString remoteName = remoteFiles.at(i);
-            int lastIndex = remoteName.count()-1;
-            if(remoteName.at(lastIndex) == '~') {
-                remoteFiles.removeAt(i);
-            }
-        }
+       QString fileName = remoteFiles.at(i);
+       if(fileName.contains("remotes.conf",Qt::CaseInsensitive) || fileName.contains("~",Qt::CaseInsensitive))
+           remoteFiles.removeAt(i);
+    }
+
+    // Fill usedThemes
+    for(int i=0;i<remoteFiles.count();i++) {
+        QFile file("/home/user/MyDocs/qtirreco/Remotes/" + remoteFiles.at(i));
+        file.open(QIODevice::ReadOnly | QIODevice::Text);
+           QTextStream in(&file);
+           while (!in.atEnd()) {
+               QString line = in.readLine();
+               this->readUsedThemes(line);
+           }
+        if(usedThemesByRemote.contains(themeToDelete,Qt::CaseInsensitive))
+            remoteNamesUsingThemeToBeDeleted.append(remoteFiles.at(i));
+        //usedThemes.clear();
+        usedThemesByRemote.clear();
+        file.close();
     }
 
 
@@ -892,6 +900,7 @@ void ThemeManager::on_deletePushButton_clicked()
 
         themeUsedInRemote = true;
         QString remoteNames;
+        remoteNamesUsingThemeToBeDeleted.removeDuplicates();
         for(int i=0;i<remoteNamesUsingThemeToBeDeleted.count();i++) {
             QString remName =  remoteNamesUsingThemeToBeDeleted.at(i);
             remName.chop(5);
@@ -900,6 +909,8 @@ void ThemeManager::on_deletePushButton_clicked()
         remoteNames.chop(1);
         QMessageBox::information(this,"Theme manager","Unable to delete theme: " + themeToDeleteName + "\nTheme used in remote: " +
                                   remoteNames, QMessageBox::NoButton,QMessageBox::NoButton);
+        remoteNames.clear();
+
 
     }
 
